==> cscec5b-fjwz-impl-3.0.1-20221205.085819-29-sources.jar: com/ejianc/business/fjwz/bean/ScarpDetailEntity.java <==
package com.ejianc.business.fjwz.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 废旧物资出场明细
 *
 * @author generator
 *
 */
 @TableName("ejc_fjwz_scarp_detail")
public class ScarpDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="scarp_id")
    private Long scarpId; // 废旧物资处置主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private String unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="num")
    private BigDecimal num; // 出场数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型 0-物料档案，1-询价结果
    @TableField(value="apply_num")
    private BigDecimal applyNum; // 处置数量
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可出场数量
    @TableField(value="source_id")
    private String sourceId; // 来源主键





    public Long getScarpId() {
        return scarpId;
    }

    public void setScarpId(Long scarpId) {
        this.scarpId = scarpId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getApplyNum() {
        return applyNum;
    }

    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
}

==> cscec5b-fjwz-impl-3.0.1-20240124.105634-88-sources.jar: com/ejianc/business/fjwz/bean/ScarpDetailEntity.java <==
package com.ejianc.business.fjwz.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 废旧物资出场明细
 *
 * @author generator
 *
 */
 @TableName("ejc_fjwz_scarp_detail")
public class ScarpDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="scarp_id")
    private Long scarpId; // 废旧物资处置主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物料分类id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物料分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private String unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="num")
    private BigDecimal num; // 出场数量
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_type")
    private Integer sourceType; // 来源类型 0-物料档案，1-询价结果
    @TableField(value="apply_num")
    private BigDecimal applyNum; // 处置数量
    @TableField(value="surplus_num")
    private BigDecimal surplusNum; // 剩余可出场数量
    @TableField(value="source_id")
    private String sourceId; // 来源主键
    @TableField(value="gross_weight")
    private BigDecimal grossWeight; // 过磅毛重
    @TableField(value="tare_weight")
    private BigDecimal tareWeight; // 过磅皮重
    @TableField(value="net_price")
    private BigDecimal netPrice; // 网价
    @TableField(value="deal_price")
    private BigDecimal dealPrice; // 处理单价
    @TableField(value="deal_mny")
    private BigDecimal dealMny; // 处理金额




    public Long getScarpId() {
        return scarpId;
    }

    public void setScarpId(Long scarpId) {
        this.scarpId = scarpId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getApplyNum() {
        return applyNum;
    }

    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getNetPrice() {
        return netPrice;
    }

    public void setNetPrice(BigDecimal netPrice) {
        this.netPrice = netPrice;
    }

    public BigDecimal getDealPrice() {
        return dealPrice;
    }

    public void setDealPrice(BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }

    public BigDecimal getDealMny() {
        return dealMny;
    }

    public void setDealMny(BigDecimal dealMny) {
        this.dealMny = dealMny;
    }
}
